@@ -45,6 +45,13 @@ ts_seasonal <- function(ts.obj,
                         palette_normal = "viridis") {
   
   `%>%` <- magrittr::`%>%`
+  
+  hex_to_rgb <- function(hex){
+    rgb <- base::paste0(as.numeric(grDevices::col2rgb(hex) %>% base::t()), collapse = ",")
+    return(rgb)
+  }
+  
+  
   df <- freq <- obj.name <- brewer_palettes <- viridis_palettes <- palette_type <- NULL
   n_colors <- color_list_normal <- main <- NULL
   diff_mean <- col_class <- date_col <-  numeric_col <- NULL
@@ -225,6 +232,8 @@ ts_seasonal <- function(ts.obj,
       df_temp <- base::data.frame(date = ts.obj[, date_col], ts.obj[, numeric_col[1]])
     }
     
+    dt_temp <- dt_temp %>% dplyr::arrange(date)
+    
     data_diff <- NULL
     date_diff <- base::diff(as.numeric(df_temp$date))
     
@@ -310,10 +319,23 @@ ts_seasonal <- function(ts.obj,
   if(type == "cycle" | type == "all"){
     df_t <- NULL
     df_t <- base::suppressMessages(df %>% reshape2::dcast(main ~ minor))
+    
+    showlegend <- legendgroup <- NULL
+    showlegend <- TRUE
+    
+    
+    
     p_cycle <- plotly::plot_ly()
     for(i in 2:ncol(df_t)){
+      legendgroup <- ifelse(type == "all", 
+                            base::paste("all", colnames(df_t)[i], sep = "_"),  
+                            base::paste("cycle", colnames(df_t)[i], sep = "_"))
       p_cycle <- p_cycle %>% 
-        plotly::add_lines(x = df_t[, 1], y = df_t[, i], name = colnames(df_t)[i], line = list(color = colors_list[i - 1]))
+        plotly::add_lines(x = df_t[, 1], y = df_t[, i], 
+                          name = colnames(df_t)[i], 
+                          line = list(color = colors_list[i - 1]), 
+                          showlegend = showlegend,
+                          legendgroup = legendgroup)
     }
     
     p_cycle <- p_cycle %>% plotly::layout(yaxis = list(title = "By Frequency Unit"))
@@ -321,17 +343,26 @@ ts_seasonal <- function(ts.obj,
   
   if(type == "box" | type == "all"){
     minor <- base::levels(df$minor)
+    showlegend <- legendgroup <- NULL
+    showlegend <- ifelse(type == "all", FALSE, TRUE)
+    
     p_box <- plotly::plot_ly()
     c <- NULL
     c <- 1
     for(i in minor){
-      p_box <- p_box %>% plotly::add_trace(data = df %>% dplyr::filter(minor == i), y = ~ y,  type = "box", 
+      legendgroup <- ifelse(type == "all", 
+                            base::paste("all", i, sep = "_"),  
+                            base::paste("box", i, sep = "_"))
+      p_box <- p_box %>% plotly::add_trace(data = df %>% dplyr::filter(minor == i), y = ~ y,  type = "box",
+                                           fillcolor = base::paste("rgba(", hex_to_rgb(colors_list[c]), ", 0.5)", sep = ""),
                                            line = list(color = colors_list[c]),
                                            marker = list(color = colors_list[c]),
                                            boxpoints = "all",
                                            jitter = 0.3,
                                            pointpos = -1.8, 
-                                           name = i)
+                                           name = i,
+                                           showlegend = showlegend,
+                                           legendgroup = legendgroup)
       c <- c + 1
     }
     p_box <- p_box %>% plotly::layout(yaxis = list(title = "By Frequency Unit"))
